from setuptools import setup

setup(name='shah_distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['shah_distributions'],
      author='Shahzeb Akhtar',
      author_email = 'shahzeb.akhtar@gmail.com',
      zip_safe=False)
